@@ -53,6 +53,8 @@ appDependencies <- function(project = NULL,
     .packrat_mutables$origLibPaths
   )
 
+  ignores <- packrat::opts$ignored.packages()
+
   ## For R packages, we only use the DESCRIPTION file
   if (isRPackage(project)) {
 
@@ -61,20 +63,22 @@ appDependencies <- function(project = NULL,
       pkgDescriptionDependencies(file.path(project, "DESCRIPTION"))$Package
 
     # Strip out any dependencies the user has requested we do not track.
-    parentDeps <- setdiff(parentDeps, packrat::opts$ignored.packages())
+    parentDeps <- setdiff(parentDeps, ignores)
 
     ## For downstream dependencies, we don't grab their Suggests:
     ## Presumedly, we can build child dependencies without vignettes, and hence
     ## do not need suggests -- for the package itself, we should make sure
     ## we grab suggests, however
     childDeps <- recursivePackageDependencies(parentDeps,
+                                              ignores,
                                               libPaths,
                                               available.packages,
                                               fields)
   } else {
     parentDeps <- setdiff(unique(c(dirDependencies(project))), "packrat")
-    parentDeps <- setdiff(parentDeps, packrat::opts$ignored.packages())
+    parentDeps <- setdiff(parentDeps, ignores)
     childDeps <- recursivePackageDependencies(parentDeps,
+                                              ignores,
                                               libPaths,
                                               available.packages,
                                               fields)
@@ -106,6 +110,86 @@ appDependencies <- function(project = NULL,
 
 # detect all package dependencies for a directory of files
 dirDependencies <- function(dir) {
+  if (as.logical(getOption("packrat.dependency.discovery.disabled", default = FALSE))) {
+    character()
+  } else if (as.logical(getOption("packrat.dependency.discovery.renv", default = TRUE))) {
+    dirDependenciesRenv(dir)
+  } else {
+    dirDependenciesBuiltIn(dir)
+  }
+}
+
+# Return renv ignore patterns based on the packrat ignored.directories option.
+# Each directory is returned as a rooted pattern for renv, meaning that it
+# should only apply at the root directory of the project.
+#
+# Note: The "/data/" and "/inst/" directories are ignored by default.
+#
+# See: https://github.com/rstudio/renv/pull/866
+#
+# See: renv:::renv_renvignore_parse_impl
+ignoresForRenv <- function(dir, ignoredDirectories) {
+  ignores <- NULL
+  if (length(ignoredDirectories) > 0) {
+    ignores <- ignoredDirectories
+    # Make sure all the directories end with a slash.
+    ignores <- ifelse(
+        substr(ignores, nchar(ignores), nchar(ignores)) != "/",
+        paste0(ignores, "/"),
+        ignores
+    )
+    # Make sure all the directories begin with a slash.
+    ignores <- ifelse(
+        substr(ignores, 1, 1) != "/",
+        paste0("/", ignores),
+        ignores
+    )
+    # Prepend the project root and quote.
+    ignores <- paste0('^\\Q', dir, '\\E\\Q', ignores, '\\E$')
+    # Tell renv that these rules do not need additional parsing.
+    attr(ignores, "asis") <- TRUE
+  }
+  ignores
+}
+
+dirDependenciesRenv <- function(dir) {
+  old_filebacked_cache <- options(renv.config.filebacked.cache = FALSE)
+  on.exit(do.call(options, old_filebacked_cache), add = TRUE)
+
+  project <- Sys.getenv("RENV_PROJECT", unset = NA)
+  if (!is.na(project)) {
+    Sys.unsetenv("RENV_PROJECT")
+    on.exit(Sys.setenv(RENV_PROJECT = project), add = TRUE)
+  }
+
+  profile <- Sys.getenv("RENV_PROFILE", unset = NA)
+  if (!is.na(profile)) {
+    Sys.unsetenv("RENV_PROFILE")
+    on.exit(Sys.setenv(RENV_PROFILE = profile), add = TRUE)
+  }
+
+  absDir <- normalizePath(dir, winslash = "/")
+
+  old_ignored_packages <- options("renv.settings.ignored.packages" = opts$ignored.packages())
+  on.exit(do.call(options, old_ignored_packages), add = TRUE)
+
+  old_renv_exclude <- options("renv.renvignore.exclude" = ignoresForRenv(absDir, opts$ignored.directories()))
+  on.exit(do.call(options, old_renv_exclude), add = TRUE)
+
+  # TODO: add rsconnect as an ignored directory? May not be an issue for
+  # bundling, since we don't include the rsconnect directory.
+
+  deps <- renv$dependencies(path = absDir, root = absDir, progress = FALSE, errors = "ignored")
+  pkgs <- unique(deps$Package)
+  ## Exclude recommended packages (and the artifical "R" package) if there is
+  ## no package installed locally this places an implicit dependency on the
+  ## system-installed version of a package
+  pkgs <- dropSystemPackages(pkgs)
+  pkgs
+}
+
+# detect all package dependencies for a directory of files
+dirDependenciesBuiltIn <- function(dir) {
   dir <- normalizePath(dir, winslash = '/')
 
   # first get the packages referred to in source code
@@ -137,20 +221,18 @@ dirDependencies <- function(dir) {
       "(?:^",
       paste0(
         ignoredDir,
-        collapse=")|(?:^"
+        collapse = ")|(?:^"
       ),
       ")"
     )
     R_files <- grep(ignoredDirRegex, R_files, invert = TRUE, value = TRUE)
   }
 
-  if (!identical(getOption("packrat.dependency.discovery.disabled"), TRUE)) {
-    sapply(R_files, function(file) {
-      filePath <- file.path(dir, file)
-      pkgs <<- append(pkgs, fileDependencies(file.path(dir, file)))
+  sapply(R_files, function(file) {
+    filePath <- file.path(dir, file)
+    pkgs <<- append(pkgs, fileDependencies(file.path(dir, file)))
 
-    })
-  }
+  })
 
   ## Exclude recommended packages if there is no package installed locally
   ## this places an implicit dependency on the system-installed version of a package
@@ -746,7 +828,7 @@ fileDependencies.tangle <- function(file, encoding = "UTF-8") {
   # parse each r chunk independently to retrieve dependencies
   # allows for some chunks to be _broken_ but not stop retrieving dependencies
   r_chunks <- strsplit(paste0(readLines(outfile), collapse = "\n"), key)[[1]]
-  for(r_chunk in r_chunks) {
+  for (r_chunk in r_chunks) {
     try(silent = TRUE, {
       parsed <- parse(text = r_chunk, encoding = encoding)
       deps <- c(deps, expressionDependencies(parsed))
