@@ -14,7 +14,8 @@
 #' packages your project depends on.
 #' \item \strong{Reproducible}: Packrat records the exact package versions you
 #' depend on, and ensures those exact versions are the ones that get installed
-#' wherever you go.}
+#' wherever you go.
+#' }
 #'
 #' Use \code{\link{init}} to create a new packrat project,
 #' \code{\link{snapshot}} to record changes to your project's library, and
@@ -67,11 +68,9 @@
 #' restore()
 #' }
 #'
-#' @docType package
-#' @name packrat
 #' @import utils
-#' @author RStudio, Inc.
-NULL
+#' @author Posit Software, PBC
+'_PACKAGE'
 
 #' Initialize Packrat on a new or existing \R project
 #'
@@ -269,14 +268,12 @@ initImpl <- function(project = getwd(),
 #'
 #' There are three common use cases for \code{restore}:
 #' \itemize{
-#'   \item \strong{Hydrate}: Use \code{restore} after copying a project to a new
-#' machine to populate the library on that machine.
-#'
-#'   \item \strong{Sync}: Use \code{restore} to apply library changes made by a
+#' \item \strong{Hydrate}: Use \code{restore} after copying a project to a new machine
+#' to populate the library on that machine.
+#' \item \strong{Sync}: Use \code{restore} to apply library changes made by a
 #' collaborator to your own library. (In general, you want to run \code{restore}
 #' whenever you pick up a change to \code{packrat.lock})
-#'
-#'   \item \strong{Rollback}: Use \code{restore} to undo accidental changes made
+#' \item \strong{Rollback}: Use \code{restore} to undo accidental changes made
 #' to the library since the last snapshot.
 #' }
 #'
@@ -284,44 +281,64 @@ initImpl <- function(project = getwd(),
 #' changes are necessary to currently loaded packages, you will need to restart
 #' \R to apply the changes (\code{restore} will let you know when this is
 #' necessary). It is recommended that you do this as soon as possible, because
-#' any library changes made between running \code{restore} and restarting \R will
-#' be lost.
+#' any library changes made between running \code{restore} and restarting \R
+#' will be lost.
 #'
-#' @note
-#' \code{restore} can be destructive; it will remove packages that were not in
-#' the snapshot, and it will replace newer packages with older versions if
-#' that's what the snapshot indicates. \code{restore} will warn you before
-#' attempting to remove or downgrade a package (if \code{prompt} is
-#' \code{TRUE}), but will always perform upgrades and new installations without
-#' prompting.
+#' @note \code{restore} can be destructive; it will remove packages that were
+#'   not in the snapshot, and it will replace newer packages with older versions
+#'   if that's what the snapshot indicates. \code{restore} will warn you before
+#'   attempting to remove or downgrade a package (if \code{prompt} is
+#'   \code{TRUE}), but will always perform upgrades and new installations
+#'   without prompting.
 #'
-#' \code{restore} works only on the private package library created by packrat;
-#' if you have other libraries on your path, they will be unaffected.
+#'   \code{restore} works only on the private package library created by
+#'   packrat; if you have other libraries on your path, they will be unaffected.
 #'
-#' The \code{restart} parameter will only result in a restart of R when the
-#' R environment packrat is running within makes available a restart function
-#' via \code{getOption("restart")}.
+#'   The \code{restart} parameter will only result in a restart of R when the R
+#'   environment packrat is running within makes available a restart function
+#'   via \code{getOption("restart")}.
 #'
-#' @param project The project directory. When in packrat mode, if this is \code{NULL},
-#' then the directory associated with the current packrat project is used. Otherwise,
-#' the project directory specified is used.
+#'   To install packages hosted in private repositories on GitHub, GitLab, and
+#'   Bitbucket, you must either set the option
+#'   \code{packrat.authenticated.downloads.use.renv} to \code{TRUE} and ensure
+#'   that \code{curl} is available on your system, or ensure that the
+#'   \code{httr} package is available in your R library.
+#'
+#'   In addition, you must make credentials for your provider available in the
+#'   appropriate environment variable(s): \code{GITHUB_PAT}, \code{GITLAB_PAT},
+#'   and/or \code{BITBUCKET_USERNAME} and \code{BITBUCKET_PASSWORD}. These
+#'   environment variables are hidden from package installation subprocesses.
+#'
+#'   Packrat does not support installation from enterprise instances of GitHub,
+#'   GitLab, or Bitbucket.
+#'
+#'   Packrat selects a \code{tar} binary with the following heuristic: If a
+#'   \code{TAR} environment variable exists, Packrat will use that. Otherwise,
+#'   it will either look for a \code{tar} binary on the \code{PATH} on Unix, or
+#'   look for the system \code{tar} on Windows. If no binary is found in those
+#'   locations, it will use R's internal \code{tar} implementation, which may
+#'   cause errors with long filenames.
+#'
+#' @param project The project directory. When in packrat mode, if this is
+#'   \code{NULL}, then the directory associated with the current packrat project
+#'   is used. Otherwise, the project directory specified is used.
 #' @param overwrite.dirty A dirty package is one that has been changed since the
-#' last snapshot or restore. Packrat will leave these alone by default. If you
-#' want to guarantee that \code{restore} will put you in the exact state
-#' represented by the snapshot being applied, use \code{overwrite.dirty = TRUE}.
+#'   last snapshot or restore. Packrat will leave these alone by default. If you
+#'   want to guarantee that \code{restore} will put you in the exact state
+#'   represented by the snapshot being applied, use \code{overwrite.dirty =
+#'   TRUE}.
 #' @param prompt \code{TRUE} to prompt before performing potentially destructive
-#' changes (package removals or downgrades); \code{FALSE} to perform these
-#' operations without confirmation.
+#'   changes (package removals or downgrades); \code{FALSE} to perform these
+#'   operations without confirmation.
 #' @param dry.run If \code{TRUE}, compute the changes to your packrat state that
 #'   would be made if a restore was performed, without actually executing them.
 #' @param restart If \code{TRUE}, restart the R session after restoring.
 #'
-#' @seealso
-#' \code{\link{snapshot}}, the command that creates the snapshots applied with
-#' \code{restore}.
+#' @seealso \code{\link{snapshot}}, the command that creates the snapshots
+#'   applied with \code{restore}.
 #'
-#' \code{\link{status}} to view the differences between the most recent snapshot
-#' and the library.
+#'   \code{\link{status}} to view the differences between the most recent
+#'   snapshot and the library.
 #'
 #' @export
 restore <- function(project = NULL,
@@ -367,8 +384,10 @@ restore <- function(project = NULL,
   packages <- lockInfo(project)
   r_version <- lockInfo(project, 'r_version')
   if (!identical(as.character(getRversion()), r_version)) {
-    warning('The most recent snapshot was generated using R version ',
-            r_version)
+    warning(
+      'The most recent snapshot was generated using R version ', r_version,
+      immediate. = TRUE
+    )
   }
 
   # See if any of the packages that are currently in the library are dirty.
@@ -582,7 +601,7 @@ packify <- function(project = NULL, quiet = FALSE) {
   invisible()
 }
 
-lockInfo <- function(project, property='packages', fatal=TRUE) {
+lockInfo <- function(project, property = 'packages', fatal = TRUE) {
 
   project <- getProjectDir(project)
 
