@@ -1,9 +1,8 @@
-context("Bundle")
-
 test_that("Bundle works when using R's internal tar", {
 
   skip_on_cran()
   skip_on_travis()
+  skip_on_ci()
   scopeTestContext()
 
   # force packrat to use the internal R tar
@@ -25,14 +24,14 @@ test_that("Bundle works when omitting CRAN packages", {
 
   skip_on_cran()
   skip_on_travis()
+  skip_on_ci()
   scopeTestContext()
 
   checker <- function() {
-    # we shouldn't see any CRAN packages in the unbundled sources
+    # we shouldn't see any CRAN packages in the unbundled sources other than Packrat
     srcDir <- "untarred/packrat-test-bundle/packrat/src"
     srcFiles <- list.files(srcDir, pattern = "tar.gz$", recursive = TRUE)
-    cat(paste(srcFiles, collapse = "\n"))
-    expect_true(length(srcFiles) == 0, "src dir should be empty")
+    expect_true(length(srcFiles) == 1, "src dir should be empty (other than Packrat)")
   }
 
   bundle_test(packrat:::bundle, checker, omit.cran.src = TRUE)
